get_required_list

Function get_required_list 

pub fn get_required_list<'py>(
    dict: &Bound<'py, PyDict>,
    key: &str,
) -> PyResult<Bound<'py, PyList>>
Helper function to get a required PyList from a Python dictionary.

Returns

Returns the extracted PyList or a PyErr if the key is missing or extraction fails.

Errors

Returns PyErr if the key is missing or value extraction fails.